@@ -110,7 +110,7 @@ TODO: Prevent crash if expr_src is unavailable when tracing...
 
 # TODO: Cache compiled ASTs!
 
-__version__ = "0.11"
+__version__ = "0.12"
 
 import sys
 import inspect
@@ -883,9 +883,15 @@ def check_expectation(exp, set_success=True):
             # Construct extra-detailed message
             extra_msg = ""
             if full_output != short_output:
-                extra_msg += f"\nFull output:\n  {full_output}"
+                extra_msg += (
+                    f'\nFull output:\n"""\n{full_output}\n"""'
+                    f' ({len(full_output)} characters)'
+                )
             if full_fragment != short_fragment:
-                extra_msg += f"\nFull fragment:\n  {full_fragment}"
+                extra_msg += (
+                    f'\nFull fragment:\n"""\n{full_fragment}\n"""'
+                    f' ({len(full_fragment)} characters)'
+                )
 
             if extra_msg.startswith('\n'):
                 extra_msg = extra_msg[1:]
